@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _CORE_H_
-#define _CORE_H_
+#ifndef CORE_H
+#define CORE_H
 
 #include <QObject>
 #include <QProcess> // For QProcess::ProcessError
@@ -27,19 +27,15 @@
 
 #include "config.h"
 
-#ifndef NO_USE_INI_FILES
 class FileSettingsBase;
-#endif
 
 class PlayerProcess;
 class MplayerWindow;
 class QSettings;
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 #ifdef SCREENSAVER_OFF
 class WinScreenSaver;
 #endif
-#endif
 
 #ifdef YOUTUBE_SUPPORT
 class RetrieveYoutubeUrl;
@@ -50,7 +46,7 @@ class Core : public QObject
     Q_OBJECT
     
 public:
-	enum State { Stopped = 0, Playing = 1, Paused = 2 };
+	enum State { Stopped = 0, Playing = 1, Paused = 2, Buffering = 3 };
 
 	Core( MplayerWindow *mpw, QWidget* parent = 0 );
 	~Core();
@@ -76,7 +72,7 @@ public slots:
 	//! Generic open, with autodetection of type
 	void open(QString file, int seek=-1); 
 	void openFile(QString filename, int seek=-1);
-	void openStream(QString name);
+	void openStream(QString name, QStringList params = QStringList());
 	/*
 	void openDVD( bool from_folder, QString directory = "");
 	void openDVD(); // Plays title 1
@@ -88,7 +84,9 @@ public slots:
 #endif
 	void openVCD(int title = -1);
 	void openAudioCD(int title = -1);
+#ifdef TV_SUPPORT
 	void openTV(QString channel_id);
+#endif
 
 #ifdef YOUTUBE_SUPPORT
 	void openYT(const QString & url);
@@ -104,15 +102,18 @@ public slots:
 	void loadAudioFile(const QString & audiofile);
 	void unloadAudioFile();
 
-    void stop(); 
-    void play();
+	void stop();
+	void play();
 	void play_or_pause();
-    void pause_and_frame_step();
+	void pause_and_frame_step();
 	void pause();
 	void frameStep();
 	void frameBackStep();
 	void screenshot();	//!< Take a screenshot of current frame
 	void screenshots();	//!< Start/stop taking screenshot of each frame
+#ifdef CAPTURE_STREAM
+	void switchCapturing();
+#endif
 
 	//! Public restart, for the GUI.
 	void restart();
@@ -121,12 +122,13 @@ public slots:
 	void reload();
 
 #ifdef SEEKBAR_RESOLUTION
-    void goToPosition( int value );
-    void goToPos( double perc );
+	void goToPosition( int value );
+	void goToPos( double perc );
 #else
-    void goToPos( int perc );
+	void goToPos( int perc );
 #endif
-    void goToSec( double sec );
+	void goToSec( double sec );
+	void goToSec(int sec) { goToSec( (double) sec); }
 
 	void setAMarker(); //!< Set A marker to current sec
 	void setAMarker(int sec);
@@ -146,10 +148,13 @@ public slots:
 	void toggleMirror(bool b);
 
 	// Audio filters
+#ifdef MPLAYER_SUPPORT
 	void toggleKaraoke();
 	void toggleKaraoke(bool b);
+#endif
 	void toggleExtrastereo();
 	void toggleExtrastereo(bool b);
+
 	void toggleVolnorm();
 	void toggleVolnorm(bool b);
 
@@ -172,19 +177,25 @@ public slots:
 	void changeDenoise(int);
 	void changeUnsharp(int);
 	void changeLetterbox(bool);
+#ifdef ADD_BLACKBORDERS_FS
 	void changeLetterboxOnFullscreen(bool);
+#endif
 	void changeUpscale(bool);
 	void changeStereo3d(const QString & in, const QString & out);
 
 	void seek(int secs);
 	void sforward(); 	// + 10 seconds
 	void srewind(); 	// - 10 seconds
-    void forward(); 	// + 1 minute
-    void rewind(); 		// -1 minute
-    void fastforward();	// + 10 minutes
-    void fastrewind();	// - 10 minutes
+	void forward(); 	// + 1 minute
+	void rewind(); 		// -1 minute
+	void fastforward();	// + 10 minutes
+	void fastrewind();	// - 10 minutes
 	void forward(int secs);
 	void rewind(int secs);
+#ifdef MPV_SUPPORT
+	void seekToNextSub();
+	void seekToPrevSub();
+#endif
 	void wheelUp();
 	void wheelDown();
 
@@ -199,9 +210,11 @@ public slots:
 	void halveSpeed();
 	void normalSpeed();
 
-    void setVolume(int volume, bool force = false);
+	void setVolume(int volume, bool force = false);
 	void switchMute();
 	void mute(bool b);
+	void incVolume(int step);
+	void decVolume(int step);
 	void incVolume();
 	void decVolume();
 
@@ -292,6 +305,11 @@ public slots:
 	void nextOSD();
 	void nextWheelFunction();
 
+#ifdef BOOKMARKS
+	void nextBookmark();
+	void prevBookmark();
+#endif
+
 	#if 0
 	void changeSize(int); // Size of the window
 	void toggleDoubleSize();
@@ -304,6 +322,8 @@ public slots:
 	void changeAdapter(int n);
 #endif
 
+	void changeAO(const QString & new_ao);
+
 	void incZoom();
 	void decZoom();
 	void resetZoom();
@@ -351,9 +371,7 @@ public:
 	int firstDVDTitle();
 	int firstBlurayTitle();
 
-#ifndef NO_USE_INI_FILES
 	void changeFileSettingsMethod(QString method);
-#endif
 
 protected:
 	//! Returns the prefix to keep pausing on slave commands
@@ -428,12 +446,10 @@ protected slots:
 	void YTNoVideoUrl();
 #endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 #ifdef SCREENSAVER_OFF
 	void enableScreensaver();
 	void disableScreensaver();
 #endif
-#endif
 
 protected:
 	void playNewFile(QString file, int seek=-1);
@@ -444,11 +460,10 @@ protected:
     void startMplayer(QString file, double seek = -1 );
 	void stopMplayer();
 
-#ifndef NO_USE_INI_FILES
 	void saveMediaInfo();
-#endif
+	void restoreSettingsForMedia(const QString & name, int type);
 
-    void initializeMenus();
+	void initializeMenus();
 	void updateWidgets();
 
 	//! Returns true if changing the subscale requires to restart mplayer
@@ -461,6 +476,7 @@ signals:
 	void aboutToStartPlaying(); // Signal emited just before to start mplayer
 	void mediaLoaded();
 	void mediaInfoChanged();
+	void mediaDataReceived(const MediaData &);
 	//! Sends the filename and title of the stream playing in this moment
 	void mediaPlaying(const QString & filename, const QString & title);
 	void stateChanged(Core::State state);
@@ -482,6 +498,7 @@ signals:
 	void newDuration(double); // Duration has changed
 	void showFrame(int frame);
 	void ABMarkersChanged(int secs_a, int secs_b);
+	void bitrateChanged(int vbitrate, int abitrate);
 	void needResize(int w, int h);
 	void noVideo();
 	void volumeChanged(int);
@@ -515,16 +532,14 @@ protected:
 	PlayerProcess * proc;
 	MplayerWindow * mplayerwindow;
 
-#ifndef NO_USE_INI_FILES
 	FileSettingsBase * file_settings;
+#ifdef TV_SUPPORT
 	FileSettingsBase * tv_settings;
 #endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 #ifdef SCREENSAVER_OFF
 	WinScreenSaver * win_screensaver;
 #endif
-#endif
 
 #ifdef YOUTUBE_SUPPORT
 	RetrieveYoutubeUrl * yt;
