@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,6 +50,10 @@
 
 #endif
 
+#if QT_VERSION >= 0x050000
+#include "myscroller.h"
+#endif
+
 //#define NO_SMPLAYER_SUPPORT
 
 #ifndef NO_SMPLAYER_SUPPORT
@@ -64,7 +68,7 @@
 #define COL_USER 5
 
 FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
-	: QDialog(parent,f)
+	: QWidget(parent,f)
 {
 	setupUi(this);
 
@@ -108,6 +112,10 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 	view->setEditTriggers(QAbstractItemView::NoEditTriggers);
 	view->setContextMenuPolicy( Qt::CustomContextMenu );
 
+#if QT_VERSION >= 0x050000
+	MyScroller::setScroller(view->viewport());
+#endif
+
 	connect(view, SIGNAL(activated(const QModelIndex &)),
             this, SLOT(itemActivated(const QModelIndex &)) );
 	connect(view->selectionModel(), SIGNAL(currentChanged(const QModelIndex &,const QModelIndex &)),
@@ -146,6 +154,8 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 
 	file_downloader = new FileDownloader(this);
 	file_downloader->setModal(false);
+	file_downloader->hide();
+
 	connect( file_downloader, SIGNAL(downloadFailed(QString)),
              this, SLOT(showError(QString)), Qt::QueuedConnection );
 	connect( file_downloader, SIGNAL(downloadFinished(const QByteArray &)),
@@ -778,6 +788,10 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 	d.setProxyType( proxy_type );
 	#endif
 
+	#ifdef DOWNLOAD_SUBS
+	d.setAppendLang(include_lang_on_filename);
+	#endif
+
 	if (d.exec() == QDialog::Accepted) {
 		os_server = d.server();
 		#ifdef OS_SEARCH_WORKAROUND
@@ -796,6 +810,10 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 		#ifdef FS_USE_PROXY
 		setupProxy();
 		#endif
+
+		#ifdef DOWNLOAD_SUBS
+		include_lang_on_filename = d.appendLang();
+		#endif
 	}
 }
 
