@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,16 +32,28 @@ class OSClient : public QObject {
 
 public:
 	OSClient(QObject* parent = 0);
+
+	QList<OSSubtitle> subtitleList() { return s_list; };
+
+#ifdef FS_USE_PROXY
 	void setProxy(const QNetworkProxy & proxy);
+#endif
+
+#ifdef OS_SEARCH_WORKAROUND
+	void setRetries(int n) { search_retries = n; };
+	int retries() { return search_retries; };
+#endif
 
 public slots:
 	void setServer(const QString & server);
 	void search(const QString & hash, qint64 file_size);
-	QList<OSSubtitle> subtitleList() { return s_list; };
 
 private slots:
 	void login();
 	void doSearch();
+#ifdef OS_SEARCH_WORKAROUND
+	void doSearch(int nqueries);
+#endif
 
 	void gotFault(int, const QString &);
 
@@ -61,6 +73,10 @@ private:
 	bool logged_in;
 	QString search_hash;
 	qint64 search_size;
+#ifdef OS_SEARCH_WORKAROUND
+	int best_search_count;
+	int search_retries;
+#endif
 	QList <OSSubtitle> s_list;
 };
 
