@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ using namespace Global;
 MPVProcess::MPVProcess(QObject * parent)
 	: PlayerProcess(parent)
 	, notified_mplayer_is_running(false)
+	, notified_pause(false)
 	, received_end_of_file(false)
 	, last_sub_id(-1)
 	, mplayer_svn(-1) // Not found yet
@@ -55,6 +56,9 @@ MPVProcess::MPVProcess(QObject * parent)
 #endif
 	, dvd_current_title(-1)
 	, br_current_title(-1)
+#ifdef OSD_WITH_TIMER
+	, osd_timer(0)
+#endif
 {
 	player_id = PlayerID::MPV;
 
@@ -67,7 +71,7 @@ MPVProcess::MPVProcess(QObject * parent)
 	connect( this, SIGNAL(error(QProcess::ProcessError)),
              this, SLOT(gotError(QProcess::ProcessError)) );
 
-	int svn = MplayerVersion::mplayerVersion("mpv unknown version (C)");
+	/* int svn = MplayerVersion::mplayerVersion("mpv unknown version (C)"); */
 }
 
 MPVProcess::~MPVProcess() {
@@ -76,6 +80,7 @@ MPVProcess::~MPVProcess() {
 bool MPVProcess::start() {
 	md.reset();
 	notified_mplayer_is_running = false;
+	notified_pause = false;
 	last_sub_id = -1;
 	mplayer_svn = -1; // Not found yet
 	received_end_of_file = false;
@@ -110,7 +115,7 @@ bool MPVProcess::start() {
 }
 
 #ifdef CUSTOM_STATUS
-static QRegExp rx_mpv_av("^STATUS: ([0-9\\.-]+) / ([0-9\\.-]+) P: (yes|no) B: (yes|no) I: (yes|no)");
+static QRegExp rx_mpv_av("^STATUS: ([0-9\\.-]+) / ([0-9\\.-]+) P: (yes|no) B: (yes|no) I: (yes|no) VB: ([0-9\\.-]+) AB: ([0-9\\.-]+)");
 #else
 static QRegExp rx_mpv_av("^(\\((.*)\\) |)(AV|V|A): ([0-9]+):([0-9]+):([0-9]+) / ([0-9]+):([0-9]+):([0-9]+)"); //AV: 00:02:15 / 00:09:56
 #endif
@@ -122,9 +127,9 @@ static QRegExp rx_mpv_paused("^\\(Paused\\)");
 static QRegExp rx_mpv_endoffile("^Exiting... \\(End of file\\)");
 
 //static QRegExp rx_mpv_audio("^\\[stream\\] Audio .* --aid=(\\d+)( --alang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
-static QRegExp rx_mpv_audio("^.* Audio\\s+--aid=(\\d+)( --alang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
+static QRegExp rx_mpv_audio("^.* Audio\\s+--aid=(\\d+)( --alang=([a-zA-Z-]+)|)([ \\(\\)\\*]+)('(.*)'|)");
 //static QRegExp rx_mpv_subs("^\\[stream\\] Subs .* --sid=(\\d+)( --slang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
-static QRegExp rx_mpv_subs("^.* Subs\\s+--sid=(\\d+)( --slang=([a-z]+)|)([ \\(\\)\\*]+)('(.*)'|)");
+static QRegExp rx_mpv_subs("^.* Subs\\s+--sid=(\\d+)( --slang=([a-zA-Z-]+)|)([ \\(\\)\\*]+)('(.*)'|)");
 #if !NOTIFY_VIDEO_CHANGES
 //static QRegExp rx_mpv_video("^\\[stream\\] Video .* --vid=(\\d+)([ \\(\\)\\*]+)('(.*)'|)");
 static QRegExp rx_mpv_video("^.* Video\\s+--vid=(\\d+)([ \\(\\)\\*]+)('(.*)'|)");
@@ -155,11 +160,12 @@ static QRegExp rx_mpv_playing("^Playing:.*|^\\[ytdl_hook\\].*");
 //static QRegExp rx_mpv_generic("^(.*)=(.*)");
 static QRegExp rx_mpv_generic("^([A-Z_]+)=(.*)");
 
-static QRegExp rx_stream_title("icy-title: (.*)");
+static QRegExp rx_mpv_stream_title("icy-title: (.*)");
 
+static QRegExp rx_mpv_debug("^(INFO|METADATA)_.*=\\$.*");
 
 void MPVProcess::parseLine(QByteArray ba) {
-	//qDebug("MPVProcess::parseLine: '%s'", ba.data() );
+	//qDebug() << "MPVProcess::parseLine:" << ba;
 
 	if (ba.isEmpty()) return;
 
@@ -177,10 +183,17 @@ void MPVProcess::parseLine(QByteArray ba) {
 #endif
 
 	if (verbose) {
-		line = line.replace("[statusline] ", "");
-		line = line.replace("[cplayer] ", "");
+		line.replace("[statusline] ", "");
+		line.replace("[cplayer] ", "");
+		line.replace("[term-msg] ", "");
+
+		if (rx_mpv_debug.indexIn(line) > -1) {
+			line = "[debug] " + line;
+		}
 	}
 
+	static double last_sec = -1;
+
 	// Parse A: V: line
 	//qDebug("MPVProcess::parseLine: %s", line.toUtf8().data());
 	if (rx_mpv_av.indexIn(line) > -1) {
@@ -190,6 +203,8 @@ void MPVProcess::parseLine(QByteArray ba) {
 		bool paused = (rx_mpv_av.cap(3) == "yes");
 		bool buffering = (rx_mpv_av.cap(4) == "yes");
 		bool idle = (rx_mpv_av.cap(5) == "yes");
+		int video_bitrate = rx_mpv_av.cap(6).toInt();
+		int audio_bitrate = rx_mpv_av.cap(7).toInt();
 
 		if (length != md.duration) {
 			md.duration = length;
@@ -198,23 +213,43 @@ void MPVProcess::parseLine(QByteArray ba) {
 			#endif
 		}
 
+		if (paused && notified_pause) {
+			if (last_sec != sec) {
+				last_sec = sec;
+				emit receivedCurrentSec(sec);
+				emit receivedPause();
+			}
+			return;
+		}
+
 		if (paused) {
+			notified_pause = true;
 			qDebug("MPVProcess::parseLine: paused");
-			receivedPause();
+			emit receivedPause();
 			return;
 		}
 		else
 		if (buffering) {
 			qDebug("MPVProcess::parseLine: buffering");
-			receivedBuffering();
+			emit receivedBuffering();
 			return;
 		}
 		else
 		if (idle) {
 			qDebug("MPVProcess::parseLine: idle");
-			receivedBuffering();
+			emit receivedBuffering();
 			return;
 		}
+		notified_pause = false;
+
+		if (video_bitrate != md.video_bitrate) {
+			md.video_bitrate = video_bitrate;
+			emit receivedVideoBitrate(video_bitrate);
+		}
+		if (audio_bitrate != md.audio_bitrate) {
+			md.audio_bitrate = audio_bitrate;
+			emit receivedAudioBitrate(audio_bitrate);
+		}
 
 		#else
 
@@ -240,12 +275,12 @@ void MPVProcess::parseLine(QByteArray ba) {
 		}
 
 		if (status == "Paused") {
-			receivedPause();
+			emit receivedPause();
 			return;
 		}
 		else
 		if ((status == "...") || (status == "Buffering")) {
-			receivedBuffering();
+			emit receivedBuffering();
 			return;
 		}
 
@@ -304,6 +339,11 @@ void MPVProcess::parseLine(QByteArray ba) {
 		if (!notified_mplayer_is_running) {
 			qDebug("MPVProcess::parseLine: starting sec: %f", sec);
 
+			if (md.video_width == 0 || md.video_height == 0) {
+				md.novideo = true;
+				emit receivedNoVideo();
+			}
+
 			/*
 			if ( (md.n_chapters <= 0) && (dvd_current_title > 0) && 
                  (md.titles.find(dvd_current_title) != -1) )
@@ -332,7 +372,9 @@ void MPVProcess::parseLine(QByteArray ba) {
 			notified_mplayer_is_running = true;
 
 			// Wait some secs to ask for bitrate
+			/*
 			QTimer::singleShot(12000, this, SLOT(requestBitrateInfo()));
+			*/
 		}
 
 		emit receivedCurrentSec( sec );
@@ -403,8 +445,8 @@ void MPVProcess::parseLine(QByteArray ba) {
 		}
 		else
 
-		if (rx_stream_title.indexIn(line) > -1) {
-			QString s = rx_stream_title.cap(1);
+		if (rx_mpv_stream_title.indexIn(line) > -1) {
+			QString s = rx_mpv_stream_title.cap(1);
 			qDebug("MPVProcess::parseLine: stream_title: '%s'", s.toUtf8().data());
 			md.stream_title = s;
 			emit receivedStreamTitle(s);
@@ -693,9 +735,20 @@ void MPVProcess::parseLine(QByteArray ba) {
 				}
 			}
 			else
+			if (tag == "INFO_STREAM_PATH") {
+				QRegExp rx("edl://%\\d+%(.*)");
+				if (rx.indexIn(line) > -1) {
+					md.stream_path = rx.cap(1);
+				} else {
+					md.stream_path = value;
+				}
+			}
+			else
 			if (tag == "MPV_VERSION") {
 				mpv_version = value;
-				//qDebug("MPVProcess::parseLine: mpv version: %s", mpv_version.toUtf8().constData());
+				if (mpv_version.startsWith("mpv ")) mpv_version = mpv_version.mid(4);
+				qDebug() << "MPVProcess::parseLine: mpv version:" << mpv_version;
+				MplayerVersion::mplayerVersion("mpv " + mpv_version + " (C)");
 			}
 #if NOTIFY_VIDEO_CHANGES || NOTIFY_AUDIO_CHANGES || NOTIFY_SUB_CHANGES
 			else
@@ -719,10 +772,12 @@ void MPVProcess::requestChapterInfo() {
 	writeToStdin("print_text \"INFO_CHAPTERS=${=chapters}\"");
 }
 
+/*
 void MPVProcess::requestBitrateInfo() {
 	writeToStdin("print_text INFO_VIDEO_BITRATE=${=video-bitrate}");
 	writeToStdin("print_text INFO_AUDIO_BITRATE=${=audio-bitrate}");
 }
+*/
 
 #if NOTIFY_AUDIO_CHANGES
 void MPVProcess::updateAudioTrack(int ID, const QString & name, const QString & lang) {
